==> zn-plugin-workflow-0.1.5.tgz: package/src/controller/My.js <==
zn.define(function () {

    var STATE = {
        GOING: 1,
        PASSED: 2,
        ENDED: -1,
        CANCELED: -2,
        P_GOING: 100,
        P_PASS: 101,
        P_DENY: -101
    }

    return zn.Controller('my',{
        methods: {
            applys: {
                method: 'GET/POST',
                value: function (request, response, chain){
                    var _where = request.getValue("where");
                    this.collection('ZNPluginWorkflowInstance')
                        .paging({
                            fields: [
                                'id', 'code', 'state', 'zn_create_time', 'zn_modify_time', 'zn_note',
                                'zn_plugin_workflow_convert_index(index_id) as index_id_convert',
                                'zn_plugin_admin_convert_user(zn_create_user) as zn_create_user_convert',
                                'zn_plugin_workflow_convert_instance_current_state(id) as current_state'
                            ],
                            order: {
                                zn_create_time: 'desc'
                            },
                            where: [
                                'parent_id=0',
                                ' and zn_create_user=' + (request.getSessionValueByKey("id")||'-1'),
                                _where?' and '+zn.db.schema.SchemaSqlParser.parseWhere(_where, false):''
                            ]
                        })
                        .then(function (data){
                            response.success(data);
                        }, function (err){
                            response.error(err);
                        });
                }
            },
            todo: {
                method: 'GET/POST',
                value: function (request, response, chain){
                    var _where = request.getValue("where");
                    this.collection('ZNPluginWorkflowInstance')
                        .paging({
                            fields: [
                                'id', 'code', 'state', 'zn_create_time', 'zn_modify_time', 'zn_note',
                                'zn_plugin_workflow_convert_index(index_id) as index_id_convert',
                                'zn_plugin_admin_convert_user(zn_create_user) as zn_create_user_convert',
                                'zn_plugin_workflow_convert_instance_current_state(id) as current_state'
                            ],
                            order: {
                                zn_create_time: 'desc'
                            },
                            where: [
                                'parent_id=0',
                                ' and state=' + STATE.GOING,
                                ' and ' + zn.sql.rights(),
                                _where?' and '+zn.db.schema.SchemaSqlParser.parseWhere(_where, false):''
                            ]
                        })
                        .then(function (data){
                            response.success(data);
                        }, function (err){
                            response.error(err);
                        });
                }
            },
            done: {
                method: 'GET/POST',
                value: function (request, response, chain){
                    var _where = request.getValue("where");
                    this.collection('ZNPluginWorkflowInstance')
                        .paging({
                            fields: [
                                'id', 'code', 'state', 'zn_create_time', 'zn_modify_time', 'zn_note',
                                'zn_plugin_workflow_convert_index(index_id) as index_id_convert',
                                'zn_plugin_admin_convert_user(zn_create_user) as zn_create_user_convert',
                                'zn_plugin_workflow_convert_instance_current_state(id) as current_state'
                            ],
                            order: {
                                zn_create_time: 'desc'
                            },
                            where: [
                                'parent_id=0',
                                " and locate(',"+request.getSessionValueByKey("id")+",', do_users)<>0",
                                _where?' and '+zn.db.schema.SchemaSqlParser.parseWhere(_where, false):''
                            ]
                        })
                        .then(function (data){
                            response.success(data);
                        }, function (err){
                            response.error(err);
                        });
                }
            }
        }
    });

});

==> zn-plugin-workflow-0.1.14.tgz: package/src/controller/My.js <==
zn.define(function () {

    var STATE = {
        GOING: 1,
        PASSED: 2,
        ENDED: -1,
        CANCELED: -2,
        P_GOING: 100,
        P_PASS: 101,
        P_DENY: -101
    }

    return zn.Controller('my',{
        methods: {
            applys: {
                method: 'GET/POST',
                value: function (request, response, chain){
                    var _where = request.getValue("where");
                    this.collection('ZNPluginWorkflowInstance')
                        .paging({
                            fields: [
                                'id', 'code', 'state', 'closed', 'zn_create_time', 'zn_modify_time', 'zn_note',
                                'zn_plugin_workflow_convert_index(index_id) as index_id_convert',
                                'zn_plugin_admin_convert_user(zn_create_user) as zn_create_user_convert',
                                'zn_plugin_workflow_convert_instance_current_state(id) as current_state'
                            ],
                            order: {
                                zn_create_time: 'desc'
                            },
                            where: [
                                'parent_id=0',
                                ' and zn_create_user=' + (request.getSessionValueByKey("id")||'-1'),
                                _where?' and '+zn.db.schema.SchemaSqlParser.parseWhere(_where, false):''
                            ]
                        })
                        .then(function (data){
                            response.success(data);
                        }, function (err){
                            response.error(err);
                        });
                }
            },
            todo: {
                method: 'GET/POST',
                value: function (request, response, chain){
                    var _where = request.getValue("where");
                    this.collection('ZNPluginWorkflowInstance')
                        .paging({
                            fields: [
                                'id', 'code', 'state','closed', 'zn_create_time', 'zn_modify_time', 'zn_note',
                                'zn_plugin_workflow_convert_index(index_id) as index_id_convert',
                                'zn_plugin_admin_convert_user(zn_create_user) as zn_create_user_convert',
                                'zn_plugin_workflow_convert_instance_current_state(id) as current_state'
                            ],
                            order: {
                                zn_create_time: 'desc'
                            },
                            where: [
                                'parent_id=0',
                                ' and state=' + STATE.GOING,
                                ' and ' + zn.sql.rights(),
                                _where?' and '+zn.db.schema.SchemaSqlParser.parseWhere(_where, false):''
                            ]
                        })
                        .then(function (data){
                            response.success(data);
                        }, function (err){
                            response.error(err);
                        });
                }
            },
            done: {
                method: 'GET/POST',
                value: function (request, response, chain){
                    var _where = request.getValue("where");
                    this.collection('ZNPluginWorkflowInstance')
                        .paging({
                            fields: [
                                'id', 'code', 'state', 'closed', 'zn_create_time', 'zn_modify_time', 'zn_note',
                                'zn_plugin_workflow_convert_index(index_id) as index_id_convert',
                                'zn_plugin_admin_convert_user(zn_create_user) as zn_create_user_convert',
                                'zn_plugin_workflow_convert_instance_current_state(id) as current_state'
                            ],
                            order: {
                                zn_create_time: 'desc'
                            },
                            where: [
                                'parent_id=0',
                                " and locate(',"+request.getSessionValueByKey("id")+",', do_users)<>0",
                                _where?' and '+zn.db.schema.SchemaSqlParser.parseWhere(_where, false):''
                            ]
                        })
                        .then(function (data){
                            response.success(data);
                        }, function (err){
                            response.error(err);
                        });
                }
            }
        }
    });

});
